@@ -37,6 +37,10 @@
 @property(nonatomic,strong) AudioController *audioController;
 @property(nonatomic,strong) NuiSdkUtils *utils;
 @property(nonatomic) int ttsSampleRate;
+
+@property (nonatomic, assign) BOOL isPlaying;
+@property (nonatomic, assign) BOOL shouldStopSending; // 控制发送线程退出
+@property (nonatomic, strong) NSString *currentSessionId; // 当前会话ID，用于匹配
 @end
 
 @implementation DashCosyVoiceStreamInputTTSViewController
@@ -44,8 +48,6 @@
 #define SCREEN_WIDTH_BASE 375
 #define SCREEN_HEIGHT_BASE 667
 
-static BOOL continuousPlaybackFlag = NO;
-static BOOL SegmentFinishPlaying = NO;
 static dispatch_queue_t tts_work_queue;
 
 #pragma mark view controller methods
@@ -93,6 +95,12 @@ static dispatch_queue_t tts_work_queue;
 
 -(void)viewWillDisappear:(BOOL)animated {
     NSLog(@"%s", __FUNCTION__);
+    [super viewWillDisappear:animated];
+
+    // 触发停止
+    self.shouldStopSending = YES;
+    self.currentSessionId = @"";
+
     if (_audioController != nil) {
         [_audioController cleanPlayerBuffer];
     }
@@ -113,40 +121,18 @@ static dispatch_queue_t tts_work_queue;
 -(void)playerDidFinish {
     //播放被中止后回调。
     TLog(@"playerDidFinish");
-    SegmentFinishPlaying = YES;
-    if (continuousPlaybackFlag == NO) {
-        TLog(@"update UI of PlayButton");
-        dispatch_async(dispatch_get_main_queue(), ^{
-            // UI更新代码
-            UIImage *image = [UIImage imageNamed:@"button_start"];
-            [PlayButton setBackgroundImage:image forState:UIControlStateNormal];
-            [PlayButton setTitle:@"播放" forState:UIControlStateNormal];
-            [PlayButton removeTarget:self action:@selector(stopTTS:) forControlEvents:UIControlEventTouchUpInside];
-            [PlayButton addTarget:self action:@selector(startTTS:) forControlEvents:UIControlEventTouchUpInside];
-        });
-    }
+    _isPlaying = NO;
 }
 -(void)playerDrainDataFinish {
     //播放数据自然播放完成后回调。
     TLog(@"playerDrainDataFinish");
-    SegmentFinishPlaying = YES;
-    if (continuousPlaybackFlag == NO) {
-        TLog(@"update UI of PlayButton");
-        dispatch_async(dispatch_get_main_queue(), ^{
-            // UI更新代码
-            UIImage *image = [UIImage imageNamed:@"button_start"];
-            [PlayButton setBackgroundImage:image forState:UIControlStateNormal];
-            [PlayButton setTitle:@"播放" forState:UIControlStateNormal];
-            [PlayButton removeTarget:self action:@selector(stopTTS:) forControlEvents:UIControlEventTouchUpInside];
-            [PlayButton addTarget:self action:@selector(startTTS:) forControlEvents:UIControlEventTouchUpInside];
-        });
-    }
+    _isPlaying = NO;
 }
-
 #pragma mark -private methods
 
 -(NSString *)genTickets {
     NSString *debug_path = [_utils createDir];
+    // debug目录，当初始化SDK时的saveLog参数取值为YES时，该目录用于保存日志等调试信息
     TLog(@"debug_path:%@", debug_path);
 
     NSMutableDictionary *ticketJsonDict = [NSMutableDictionary dictionary];
@@ -374,7 +360,7 @@ static dispatch_queue_t tts_work_queue;
     CGSize global_size = [UIScreen mainScreen].bounds.size;
 
     // ---- StartButton ---
-    CGFloat button_width = global_size.width/SCREEN_WIDTH_BASE * 60;
+    CGFloat button_width = global_size.width/SCREEN_WIDTH_BASE * 80;
     CGFloat button_height = global_size.height/SCREEN_HEIGHT_BASE * 30;
     CGFloat new_border = (global_size.width - button_width * 4) / 5;
     CGFloat start_x = new_border;
@@ -384,7 +370,7 @@ static dispatch_queue_t tts_work_queue;
     StartButton.frame = CGRectMake(start_x, start_y, button_width, button_height);
     UIImage *image = [UIImage imageNamed:@"button_start"];
     [StartButton setBackgroundImage:image forState:UIControlStateNormal];
-    [StartButton setTitle:@"合成" forState:UIControlStateNormal];
+    [StartButton setTitle:@"流式合成" forState:UIControlStateNormal];
     [StartButton setTitleColor:UIColor.blackColor forState:UIControlStateNormal];
     StartButton.titleLabel.font = [UIFont systemFontOfSize:18];
     [StartButton addTarget:self action:@selector(startTTS:) forControlEvents:UIControlEventTouchUpInside];
@@ -548,7 +534,7 @@ static dispatch_queue_t tts_work_queue;
     CGFloat division = global_size.height/SCREEN_HEIGHT_BASE * 10;
     CGFloat end_y = 0;
 
-    CGFloat button_start_y = global_size.height/SCREEN_HEIGHT_BASE * 70;
+    CGFloat button_start_y = global_size.height/SCREEN_HEIGHT_BASE * 100;
     end_y = [self InitButtonView:border startY:button_start_y];
 
     CGFloat hwoptions_start_y = end_y + division;
@@ -558,9 +544,102 @@ static dispatch_queue_t tts_work_queue;
     end_y = [self InitTextView:border startY:view_start_y];
 }
 
+- (void)sendTextInChunksWithSessionId:(NSString *)sessionId {
+    @autoreleasepool {
+        // 获取要发送的文本（在主线程捕获，避免跨线程访问 UI）
+        __block NSString *textToSend = nil;
+        dispatch_sync(dispatch_get_main_queue(), ^{
+            textToSend = [self->textViewContent.text copy];
+        });
+
+        if (textToSend.length == 0) {
+            TLog(@"No text to send.");
+            return;
+        }
+
+        // 按句子切分（简单按句号、问号、感叹号分割）
+        NSCharacterSet *delimiters = [NSCharacterSet characterSetWithCharactersInString:@".。!！?？\n"];
+        NSArray<NSString *> *sentences = [textToSend componentsSeparatedByCharactersInSet:delimiters];
+        
+        // 过滤空句子
+        NSMutableArray<NSString *> *validSentences = [NSMutableArray array];
+        for (NSString *originalSentence in sentences) {
+            NSString *trimmedSentence = [originalSentence stringByTrimmingCharactersInSet:[NSCharacterSet whitespaceAndNewlineCharacterSet]];
+            if (trimmedSentence.length > 0) {
+                [validSentences addObject:trimmedSentence];
+            }
+        }
+
+        TLog(@"Total sentences to send: %lu", (unsigned long)validSentences.count);
+
+        // 逐句发送
+        for (NSUInteger i = 0; i < validSentences.count; i++) {
+            // 检查是否被要求停止
+            __block BOOL shouldStop = NO;
+            dispatch_sync(dispatch_get_main_queue(), ^{
+                shouldStop = (self.shouldStopSending || ![self.currentSessionId isEqualToString:sessionId]);
+            });
+            if (shouldStop) {
+                TLog(@"Sending stopped by user or new session.");
+                break;
+            }
+
+            NSString *sentence = validSentences[i];
+            TLog(@"Sending sentence %lu: %@", (unsigned long)(i+1), sentence);
+
+            // 调用 SDK 发送
+            int ret = [_streamInputTtsSdk sendStreamInputTts:[sentence UTF8String]];
+            if (ret != SUCCESS) {
+                TLog(@"sendStreamInputTts failed (%d) for sentence: %@", ret, sentence);
+                break;
+            }
+
+            // 等待 1 秒（但允许提前退出）
+            if (i < validSentences.count - 1) { // 最后一句不等
+                NSDate *startTime = [NSDate date];
+                NSTimeInterval waitTime = 0.5;
+                while ([[NSDate date] timeIntervalSinceDate:startTime] < waitTime) {
+                    usleep(100000); // 休眠 0.1 秒
+                    __block BOOL stopNow = NO;
+                    dispatch_sync(dispatch_get_main_queue(), ^{
+                        stopNow = (self.shouldStopSending || ![self.currentSessionId isEqualToString:sessionId]);
+                    });
+                    if (stopNow) {
+                        TLog(@"Early exit from waiting.");
+                        break;
+                    }
+                }
+            }
+        } // for
+
+        // 通过sendStreamInputTts发送完所有文本后，必须调用asyncStopStreamInputTts或者stopStreamInputTts
+        // 通知服务完成合成任务。否则会有超时报错。
+        if (validSentences.count > 0) {
+            [_streamInputTtsSdk asyncStopStreamInputTts];
+        }
+
+        // 清理会话
+        dispatch_async(dispatch_get_main_queue(), ^{
+            if ([self.currentSessionId isEqualToString:sessionId]) {
+                self.currentSessionId = @"";
+            }
+        });
+    }
+}
+
+
 #pragma mark - Button Action
 - (IBAction)startTTS:(UIButton *)sender {
+    if (_isPlaying) {
+        return;
+    }
     if (_streamInputTtsSdk != nil) {
+        // 防止重复启动
+        if (self.shouldStopSending == NO && self.currentSessionId.length > 0) {
+            TLog(@"Already running a session.");
+            return;
+        }
+
         if (_audioController == nil) {
             // 注意：这里audioController模块仅用于播放示例，用户可根据业务场景自行实现这部分代码
             _audioController = [[AudioController alloc] init:only_player];
@@ -573,15 +652,35 @@ static dispatch_queue_t tts_work_queue;
         NSString *parameters = [self genParameters:NO];
 
         dispatch_async(tts_work_queue, ^{
-            int ret = [_streamInputTtsSdk startStreamInputTts:[tickets UTF8String] parameters:[parameters UTF8String] sessionId:nil logLevel:NUI_LOG_LEVEL_DEBUG saveLog:YES];
+            NSUUID *uuid = [NSUUID UUID];
+            NSString *uuidString = [uuid UUIDString];
+            int ret = [_streamInputTtsSdk startStreamInputTts:[tickets UTF8String]
+                                                   parameters:[parameters UTF8String]
+                                                    sessionId:[uuidString UTF8String]
+                                                     logLevel:NUI_LOG_LEVEL_VERBOSE
+                                                      saveLog:YES];
             if (ret != SUCCESS) {
                 TLog(@"stream input tts start fail(%d)", ret);
+            } else {
+                TLog(@"stream input tts start success with id(%@)", uuidString);
+                
+                _isPlaying = YES;
+
+                self.currentSessionId = uuidString;
+                self.shouldStopSending = NO;
+                // 启动发送线程（在同一个 queue，避免并发问题）
+                dispatch_async(tts_work_queue, ^{
+                    [self sendTextInChunksWithSessionId:uuidString];
+                });
             }
         });
     }
 }
 
 - (IBAction)playTTS:(UIButton *)sender {
+    if (_isPlaying) {
+        return;
+    }
     if (_streamInputTtsSdk != nil) {
         if (_audioController == nil) {
             // 注意：这里audioController模块仅用于播放示例，用户可根据业务场景自行实现这部分代码
@@ -595,14 +694,20 @@ static dispatch_queue_t tts_work_queue;
         NSString *parameters = [self genParameters:YES];
 
         dispatch_async(tts_work_queue, ^{
+            NSUUID *uuid = [NSUUID UUID];
+            NSString *uuidString = [uuid UUIDString];
             int ret = [_streamInputTtsSdk asyncPlayStreamInputTts:[tickets UTF8String]
                                                        parameters:[parameters UTF8String]
                                                              text:[self->textViewContent.text UTF8String]
-                                                        sessionId:nil
+                                                        sessionId:[uuidString UTF8String]
                                                          logLevel:NUI_LOG_LEVEL_DEBUG
                                                           saveLog:YES];
             if (ret != SUCCESS) {
                 TLog(@"stream input tts play fail(%d)", ret);
+            } else {
+                TLog(@"stream input tts play success with id(%@)", uuidString);
+                
+                _isPlaying = YES;
             }
         });
     }
@@ -611,7 +716,12 @@ static dispatch_queue_t tts_work_queue;
 - (IBAction)stopTTS:(UIButton *)sender {
     if (_streamInputTtsSdk != nil) {
         TLog(@"DashCosyVoiceStreamInputTTSViewController stop tts");
-
+        
+        // 设置停止标志
+        dispatch_async(dispatch_get_main_queue(), ^{
+            self.shouldStopSending = YES;
+        });
+        
         dispatch_async(tts_work_queue, ^{
             [_streamInputTtsSdk asyncStopStreamInputTts];
         });
@@ -624,12 +734,19 @@ static dispatch_queue_t tts_work_queue;
     if (_streamInputTtsSdk != nil) {
         TLog(@"DashCosyVoiceStreamInputTTSViewController cancel tts");
 
+        // 设置停止标志
+        dispatch_async(dispatch_get_main_queue(), ^{
+            self.shouldStopSending = YES;
+        });
+        
         dispatch_async(tts_work_queue, ^{
             [_streamInputTtsSdk cancelStreamInputTts];
             if (_audioController != nil) {
                 [_audioController stopPlayer];
             }
         });
+        
+        _isPlaying = NO;
     } else {
         TLog(@"in cancelTTS, _streamInputTtsSdk == nil.");
     }
@@ -637,7 +754,7 @@ static dispatch_queue_t tts_work_queue;
 
 #pragma stream input tts callback
 - (void)onStreamInputTtsEventCallback:(StreamInputTtsCallbackEvent)event taskId:(char*)taskid sessionId:(char*)sessionId ret_code:(int)ret_code error_msg:(char*)error_msg timestamp:(char*)timestamp all_response:(char*)all_response {
-//    NSString *log = [NSString stringWithFormat:@"\n事件回调（%d）：%s", event, all_response];
+//    NSString *log = [NSString stringWithFormat:@"事件回调（%d）taskid(%s) sessionid(%s)：%s, err: %s", event, taskid, sessionId, all_response, error_msg];
 //    TLog(@"%@", log);
 
     if (event == TTS_EVENT_SYNTHESIS_STARTED) {
@@ -672,23 +789,22 @@ static dispatch_queue_t tts_work_queue;
                 }
             }
             
+            NSString *content = [NSString stringWithFormat:@"TTS_EVENT_TASK_FAILED error_message(%s) error_code(%@)",
+                                  error_msg,
+                                   errorCode];
             dispatch_async(dispatch_get_main_queue(), ^{
-                NSString *content = [NSString stringWithFormat:@"TTS_EVENT_TASK_FAILED error_message(%s) error_code(%@)",
-                                      error_msg,
-                                       errorCode];
                 self->textViewEvent.text = content;
             });
-            TLog(@"onStreamInputTtsEventCallback TTS_EVENT_END");
-
-        } else {
-            dispatch_async(dispatch_get_main_queue(), ^{
-                self->textViewEvent.text = @"TTS_EVENT_SYNTHESIS_COMPLETE";
-            });
-            TLog(@"onStreamInputTtsEventCallback (%d) TTS_EVENT_TASK_FAILED", event);
+            TLog(@"onStreamInputTtsEventCallback TTS_EVENT_TASK_FAILED");
             if (_audioController != nil) {
                 // 取消播报、或者发生异常时终止播放
                 [_audioController stopPlayer];
             }
+        } else {
+            dispatch_async(dispatch_get_main_queue(), ^{
+                self->textViewEvent.text = @"TTS_EVENT_SYNTHESIS_COMPLETE";
+            });
+            TLog(@"onStreamInputTtsEventCallback (%d) TTS_EVENT_SYNTHESIS_COMPLETE", event);
         }
     }
 }
